@@ -56,21 +56,21 @@ class EdgeWorkerState(str, Enum):
     IDLE = "idle"
     """Edge Worker is active and waiting for a task."""
     SHUTDOWN_REQUEST = "shutdown request"
-    """Request to shutdown Edge Worker."""
+    """Request to shutdown Edge Worker is issued. It will be picked-up on the next heartbeat, tasks will drain and then worker will terminate."""
     TERMINATING = "terminating"
-    """Edge Worker is completing work and stopping."""
+    """Edge Worker is completing work (draining running tasks) and stopping."""
     OFFLINE = "offline"
     """Edge Worker was shut down."""
     UNKNOWN = "unknown"
-    """No heartbeat signal from worker for some time, Edge Worker probably down."""
+    """No heartbeat signal from worker for some time, Edge Worker probably down or got disconnected."""
     MAINTENANCE_REQUEST = "maintenance request"
-    """Worker was requested to enter maintenance mode. Once worker receives this it will pause fetching jobs."""
+    """Worker was requested to enter maintenance mode. Once worker receives this message it will pause fetching tasks and drain tasks."""
     MAINTENANCE_PENDING = "maintenance pending"
-    """Edge worker received the request for maintenance, waiting for jobs to finish. Once jobs are finished will move to 'maintenance mode'."""
+    """Edge Worker received the request for maintenance, waiting for tasks to finish. Once tasks are finished will move to 'maintenance mode'."""
     MAINTENANCE_MODE = "maintenance mode"
-    """Edge worker is in maintenance mode. It is online but pauses fetching jobs."""
+    """Edge Worker is in maintenance mode. It is online but pauses fetching tasks."""
     MAINTENANCE_EXIT = "maintenance exit"
-    """Request worker to exit maintenance mode. Once the worker receives this state it will un-pause and fetch new jobs."""
+    """Request Worker is requested to exit maintenance mode. Once the worker receives this state it will un-pause and fetch new tasks."""
     OFFLINE_MAINTENANCE = "offline maintenance"
     """Worker was shut down in maintenance mode. It will be in maintenance mode when restarted."""
 
@@ -109,7 +109,7 @@ class EdgeWorkerModel(Base, LoggingMixin):
         super().__init__()
 
     @property
-    def sysinfo_json(self) -> dict:
+    def sysinfo_json(self) -> dict | None:
         return json.loads(self.sysinfo) if self.sysinfo else None
 
     @property
@@ -264,7 +264,12 @@ def change_maintenance_comment(
     """Write maintenance comment in the db."""
     query = select(EdgeWorkerModel).where(EdgeWorkerModel.worker_name == worker_name)
     worker: EdgeWorkerModel = session.scalar(query)
-    if worker.state in (EdgeWorkerState.MAINTENANCE_MODE, EdgeWorkerState.OFFLINE_MAINTENANCE):
+    if worker.state in (
+        EdgeWorkerState.MAINTENANCE_MODE,
+        EdgeWorkerState.MAINTENANCE_PENDING,
+        EdgeWorkerState.MAINTENANCE_REQUEST,
+        EdgeWorkerState.OFFLINE_MAINTENANCE,
+    ):
         worker.maintenance_comment = maintenance_comment
     else:
         error_message = f"Cannot change maintenance comment as {worker_name} is not in maintenance!"
@@ -283,3 +288,37 @@ def request_shutdown(worker_name: str, session: Session = NEW_SESSION) -> None:
         EdgeWorkerState.UNKNOWN,
     ):
         worker.state = EdgeWorkerState.SHUTDOWN_REQUEST
+
+
+@provide_session
+def add_worker_queues(worker_name: str, queues: list[str], session: Session = NEW_SESSION) -> None:
+    """Add queues to an edge worker."""
+    query = select(EdgeWorkerModel).where(EdgeWorkerModel.worker_name == worker_name)
+    worker: EdgeWorkerModel = session.scalar(query)
+    if worker.state in (
+        EdgeWorkerState.OFFLINE,
+        EdgeWorkerState.OFFLINE_MAINTENANCE,
+        EdgeWorkerState.UNKNOWN,
+    ):
+        error_message = f"Cannot add queues to edge worker {worker_name} as it is in {worker.state} state!"
+        logger.error(error_message)
+        raise TypeError(error_message)
+    worker.add_queues(queues)
+
+
+@provide_session
+def remove_worker_queues(worker_name: str, queues: list[str], session: Session = NEW_SESSION) -> None:
+    """Remove queues from an edge worker."""
+    query = select(EdgeWorkerModel).where(EdgeWorkerModel.worker_name == worker_name)
+    worker: EdgeWorkerModel = session.scalar(query)
+    if worker.state in (
+        EdgeWorkerState.OFFLINE,
+        EdgeWorkerState.OFFLINE_MAINTENANCE,
+        EdgeWorkerState.UNKNOWN,
+    ):
+        error_message = (
+            f"Cannot remove queues from edge worker {worker_name} as it is in {worker.state} state!"
+        )
+        logger.error(error_message)
+        raise TypeError(error_message)
+    worker.remove_queues(queues)
